| Copyright | (c) OleksandrZhabenko 2020 |
|---|---|
| License | MIT |
| Maintainer | olexandr543@yahoo.com |
| Safe Haskell | Safe |
| Language | Haskell2010 |
ReplaceP
Description
A program and a library that can be used as a simple basic interface to some SoX functionality or for producing the approximately Ukrainian speech with your own recorded voice (actually it produces the needed sound representations).
Documentation
replaceP :: String -> String Source #
Function is used internally to parse a given third command line argument as a [String] representing the Ukrainian sounds, which will be produced.